@@ -1,11 +1,10 @@
 //
 // QueryResults.cs - Redland Query Results
 //
-// $Id: QueryResults.cs,v 1.8 2005/01/05 11:41:42 edd Exp $
+// $Id: QueryResults.cs 10846 2006-04-25 05:29:04Z dajobe $
 //
-// Copyright (C) 2004 David Beckett - http://purl.org/net/dajobe/
-// Institute for Learning and Research Technology - http://www.ilrt.bris.ac.uk/
-// University of Bristol - http://www.bristol.ac.uk/
+// Copyright (C) 2004-2006 David Beckett - http://purl.org/net/dajobe/
+// Copyright (C) 2004-2005 University of Bristol - http://www.bristol.ac.uk/
 //
 
 using System;
@@ -46,7 +45,11 @@ namespace Redland {
 				IntPtr iname = librdf_query_results_get_binding_name (handle, i);
 				String name = Util.UTF8PtrToString (iname);
 				IntPtr v = librdf_query_results_get_binding_value (handle, i);
-				h.Add (name, new Node (v));
+				if (v != IntPtr.Zero) {
+                                	h.Add (name, new Node (v));
+                                } else {
+					h.Add (name, null);
+                                }
 			}
 
 			return h;
@@ -94,8 +97,11 @@ namespace Redland {
 		public Stream AsStream ()
 		{
 			IntPtr raw_ret = librdf_query_results_as_stream (handle);
-			// FIXME: throw exception if zero?
-			return new Stream (raw_ret);
+                        // FIXME: throw exception if zero?
+			if(raw_ret != IntPtr.Zero)
+                        	return new Stream (raw_ret);
+                        else 
+                          	return null;
 		}
 
 		// These Binding* methods apply to the current position in the
@@ -104,7 +110,10 @@ namespace Redland {
 		public Node BindingValue (int offset)
 		{
  			IntPtr v = librdf_query_results_get_binding_value (handle, offset);
-			return new Node (v); // do_not_copy=1 FIXME
+			if (v != IntPtr.Zero)
+				return new Node (v); // do_not_copy=1 FIXME
+			else
+				return null;
 		}
 
 		public string BindingName (int offset) 
@@ -121,7 +130,10 @@ namespace Redland {
 			IntPtr iname = Util.StringToHGlobalUTF8 (name.ToString());
  			IntPtr v = librdf_query_results_get_binding_value_by_name (handle, iname);
 			Marshal.FreeHGlobal (iname);
-			return new Node (v); // do_not_copy=1 FIXME
+			if (v != IntPtr.Zero)
+				return new Node (v); // do_not_copy=1 FIXME
+			else
+				return null;
 		}
 
 		public int BindingsCount ()
