@@ -1,7 +1,7 @@
 //
 // Stream.cs: Redland Statement Stream class.
 //
-// $Id: Stream.cs,v 1.7 2005/01/05 11:41:42 edd Exp $
+// $Id: Stream.cs 10847 2006-04-25 05:29:15Z dajobe $
 //
 // A class encapsulating a sequence of Statements, such as those
 // returned from a Model query. You should not normally find yourself
@@ -25,7 +25,7 @@ namespace Redland {
 
 		private bool disposed = false;
 		private bool started = false;
-		private Redland.World world = Redland.World.AddReference ();
+		private World world = Redland.World.AddReference ();
 
 		public HandleRef Handle {
 			get { return handle; }
@@ -38,7 +38,10 @@ namespace Redland {
 			get {
 				IntPtr raw_ret = librdf_stream_get_object (handle);
 				// FIXME: throw exception if raw_ret is zero
-				return new Statement (raw_ret);
+				if(raw_ret != IntPtr.Zero)
+					return new Statement (raw_ret);
+	                        else 
+        	                  	return null;
 			}
 		}
 
