@@ -1,11 +1,10 @@
 # 
 # RDF.py - Redland Python RDF module
 #
-# $Id: RDF.py,v 1.107 2005/06/06 19:34:15 cmdjb Exp $
+# $Id: RDF.py 10943 2006-05-04 05:39:06Z dajobe $
 #
 # Copyright (C) 2000-2005 David Beckett - http://purl.org/net/dajobe/
-# Institute for Learning and Research Technology - http://www.ilrt.bris.ac.uk/
-# University of Bristol - http://www.bristol.ac.uk/
+# Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software and part of Redland http://librdf.org/
 # 
@@ -110,7 +109,7 @@ __all__ = [ "Node",
 __version__ = "1.1"
 
 # For pydoc
-__date__ = '$Date: 2005/06/06 19:34:15 $'
+__date__ = '$Date: 2006-05-03 22:39:06 -0700 (Wed, 03 May 2006) $'
 __author__ = 'Dave Beckett - http://purl.org/net/dajobe, Edd Dumbill <edd@usefulinc.com> and Matt Biddulph <mb@picdiary.com>'
 
 # Package variables [globals]
@@ -175,6 +174,9 @@ class World(object):
 
   def __init__(self,digest_name="",uri_hash=None):
     """Create new RDF World object (constructor)"""
+    #trick to ensure function exists during module cleanup
+    self._cleanup = Redland.librdf_free_world
+
     self._world=Redland.librdf_new_world()
     Redland.librdf_world_open(self._world)
 
@@ -185,7 +187,7 @@ class World(object):
     global _debug    
     if _debug:
       print "Destroying RDF.World"
-    Redland.librdf_free_world(self._world)
+    self._cleanup(self._world)
 
 # end class World
 
@@ -289,7 +291,7 @@ class Node(object):
       elif args.has_key('language'):
         xml_language=args['language']
       else:
-        xml_language=""
+        xml_language=None
       if args.has_key('is_wf_xml'):
         is_wf_xml=args['is_wf_xml']
       else:
@@ -1050,6 +1052,7 @@ Create a model using an in-memory storage.
 
   def load(self, uri, name="", mime_type="", type_uri=None, handler=None):
     """Load triples into the Model from a URI in a syntax.
+       Returns a boolean success or failure.
 
        If no parser name is given, the parser to use is guessed.
 
@@ -1086,7 +1089,7 @@ Create a model using an in-memory storage.
       import Redland_python
       Redland_python.reset_callback()
 
-    return rc
+    return (rc != None)
 
   def to_string(self, base_uri=None, name="", mime_type="", type_uri=None):
     """Serialize the Model to a syntax.
@@ -1124,7 +1127,6 @@ Create a model using an in-memory storage.
   def execute(self,query):
     results = Redland.librdf_model_query_execute(self._model,query._query)
     if results is not None:
-      self.been_run = True
       return QueryResults(query._query,results)
     else:
       return None
@@ -1616,7 +1618,7 @@ Copy an existing URI uri1.
     return unicode(Redland.librdf_uri_to_string(self._reduri), 'utf-8')
 
   def __hash__(self):
-    return hash(self._reduri)
+    return hash(str(self))
   
   def __eq__(self,other):
     """Equality of RDF URI to another RDF URI."""
@@ -1716,6 +1718,11 @@ optional.  When any are given, they must all match.
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is None:
       raise RedlandError("A base URI is required when parsing a string")
+
+    if type(string) is unicode:
+      import Redland_python
+      string=Redland_python.unicode_to_bytes(string)
+
     my_stream=Redland.librdf_parser_parse_string_as_stream(self._parser,
       string, base_uri._reduri)
     if my_stream==None:
@@ -1724,7 +1731,7 @@ optional.  When any are given, they must all match.
 
   def parse_into_model(self, model, uri, base_uri=None, handler=None):
     """Parse into the Model model from the content at the URI, for
-       the optional base URI.
+       the optional base URI.  Returns a boolean success or failure.
         
        If handler is given, an error handler with the signature
          def handler(code, level, facility, message, line, column, byte, file, uri)
@@ -1752,7 +1759,7 @@ optional.  When any are given, they must all match.
       Redland_python.set_callback(handler)
 
     try:
-      r = Redland.librdf_parser_parse_into_model(self._parser,
+      rc = Redland.librdf_parser_parse_into_model(self._parser,
         uri._reduri, base_uri._reduri, model._model)
     except RedlandError, err:
       print "Caught error",err
@@ -1762,11 +1769,11 @@ optional.  When any are given, they must all match.
       import Redland_python
       Redland_python.reset_callback()
 
-    return 1
+    return (rc != None)
 
   def parse_string_into_model(self, model, string, base_uri, handler = None):
     """Parse into the Model model from the content string
-        with the required base URI
+        with the required base URI.  Returns a boolean success or failure.
 
        If handler is given, an error handler with the signature
          def handler(code, level, facility, message, line, column, byte, file, uri)
@@ -1785,6 +1792,10 @@ optional.  When any are given, they must all match.
       import Redland_python
       Redland_python.set_callback(handler)
 
+    if type(string) is unicode:
+      import Redland_python
+      string=Redland_python.unicode_to_bytes(string)
+
     rc=Redland.librdf_parser_parse_string_into_model(self._parser, string,
                                            base_uri._reduri, model._model)
 
@@ -1792,7 +1803,7 @@ optional.  When any are given, they must all match.
       import Redland_python
       Redland_python.reset_callback()
 
-    return rc
+    return (rc != None)
 
   def get_feature(self, uri):
     """Return the Node value of Parser feature URI uri"""
@@ -1815,20 +1826,20 @@ optional.  When any are given, they must all match.
 # end class Parser
 
 class RDFXMLParser(Parser):
-  def __init__(self, uri = None):
-    Parser.__init__(self, name = "rdfxml", mime_type="", uri=uri)
+  def __init__(self):
+    Parser.__init__(self, name = "rdfxml")
 
 class NTriplesParser(Parser):
-  def __init__(self, uri = None):
-    Parser.__init__(self, name = "ntriples", mime_type="text/plain", uri=uri)
+  def __init__(self):
+    Parser.__init__(self, name = "ntriples")
 
 class TurtleParser(Parser):
-  def __init__(self, uri = None):
-    Parser.__init__(self, name = "turtle", mime_type="application/x-turtle", uri=uri)
+  def __init__(self):
+    Parser.__init__(self, name = "turtle")
 
 class RSSTagSoupParser(Parser):
-  def __init__(self, uri = None):
-    Parser.__init__(self, name = "rss-tag-soup", mime_type="", uri=uri)
+  def __init__(self):
+    Parser.__init__(self, name = "rss-tag-soup")
 
 
 class Query(object):
@@ -1865,7 +1876,6 @@ class Query(object):
 
     self._query = Redland.librdf_new_query(_world._world, query_language, ruri, querystring, rbase_uri)
     self.result_stream = None
-    self.been_run = False
 
   def __del__(self):
     global _debug    
@@ -1877,7 +1887,6 @@ class Query(object):
   def execute(self,model):
     results = Redland.librdf_query_execute(self._query,model._model)
     if results is not None:
-      self.been_run = True
       return QueryResults(self._query,results)
     else:
       return None
@@ -1949,7 +1958,10 @@ class QueryResults(object):
     for i in range(c):
       n = Redland.librdf_query_results_get_binding_name(self._results,i)
       v = Redland.librdf_query_results_get_binding_value(self._results,i)
-      results[n] = Node(from_object=v)
+      if v is None:
+        results[n] = None
+      else:
+        results[n] = Node(from_object=v)
 
     return results
 
@@ -1980,7 +1992,10 @@ class QueryResults(object):
     if not self.is_bindings():
       raise RedlandError("Query result is not in variable bindings format")
     n=Redland.librdf_query_results_get_binding_value(self._results, offset)
-    return Node(from_object=n, do_not_copy=1)
+    if n is None:
+      return None
+    else:
+      return Node(from_object=n, do_not_copy=1)
 
   def get_binding_name(self, offset):
     """Get the name of a variable binding by offset"""
@@ -1993,7 +2008,10 @@ class QueryResults(object):
     if not self.is_bindings():
       raise RedlandError("Query result is not in variable bindings format")
     n=Redland.librdf_query_results_get_binding_value_by_name(self._results, name)
-    return Node(from_object=n, do_not_copy=1)
+    if n is None:
+      return None;
+    else:
+      return Node(from_object=n, do_not_copy=1)
 
   def get_bindings_count(self):
     """Get the number of variable bindings in the query result"""
@@ -2008,8 +2026,21 @@ class QueryResults(object):
     if self._results:
       Redland.librdf_free_query_results(self._results)
 
-  def to_file(self, name, base_uri=None):
-    """Serialize to filename name using the optional base URI."""
+  def to_file(self, name, format_uri=None, base_uri=None):
+    """Serialize to filename name in syntax format_uri using the optional base URI."""
+    if type(format_uri) is str:
+      format_uri = Uri(string = format_uri)
+    elif type(format_uri) is unicode:
+      import Redland_python
+      format_uri = Uri(string=Redland_python.unicode_to_bytes(format_uri))
+    else:
+      format_uri = None
+
+    if format_uri is not None:
+      rformat_uri = format_uri._reduri
+    else:
+      rformat_uri = None
+
     if type(base_uri) is str:
       base_uri = Uri(string = base_uri)
     elif type(base_uri) is unicode:
@@ -2019,7 +2050,7 @@ class QueryResults(object):
       rbase_uri = base_uri._reduri
     else:
       rbase_uri = None
-    return Redland.librdf_query_results_to_file(self._results, name, rbase_uri)
+    return Redland.librdf_query_results_to_file(self._results, name, rformat_uri, rbase_uri)
 
   def to_string(self, format_uri=None, base_uri=None):
     """Serialize to a string syntax format_uri using the optional base URI."""
@@ -2041,7 +2072,8 @@ class QueryResults(object):
       import Redland_python
       format_uri = Uri(string=Redland_python.unicode_to_bytes(format_uri))
     else:
-      format_uri = Uri(string="http://www.w3.org/2001/sw/DataAccess/rf1/result2")
+      format_uri = None
+
     if format_uri is not None:
       rformat_uri = format_uri._reduri
     else:
@@ -2200,7 +2232,7 @@ class RDFXMLSerializer(Serializer):
      ser=RDF.RDFXMLSerializer()
   """
   def __init__(self):
-    Serializer.__init__(self, name = "rdfxml", mime_type = "", uri = None)
+    Serializer.__init__(self, name = "rdfxml")
 
 class RDFXMLAbbrevSerializer(Serializer):
   """Redland RDF/XML with abbreviations Serializer class
@@ -2209,7 +2241,7 @@ class RDFXMLAbbrevSerializer(Serializer):
      ser=RDF.RDFXMLAbbrevSerializer()
   """
   def __init__(self):
-    Serializer.__init__(self, name = "rdfxml-abbrev", mime_type = "", uri = None)
+    Serializer.__init__(self, name = "rdfxml-abbrev")
 
 class RSS10Serializer(Serializer):
   """Redland RSS 1.0 Serializer class
@@ -2218,14 +2250,14 @@ class RSS10Serializer(Serializer):
      ser=RDF.RSS10Serializer()
   """
   def __init__(self):
-    Serializer.__init__(self, name = "rss-1.0", uri = None)
+    Serializer.__init__(self, name = "rss-1.0")
 
 
 class NS(object):
   """ Redland Namespace Utility Class
 
   import RDF
-  nspace = RDF.NS("http://example.com/foo")
+  nspace = RDF.NS("http://example.com/foo#")
 
   # creates an RDF Node for http://example.com/foo#blah   
   node1 = nspace.blah
@@ -2240,19 +2272,19 @@ class NS(object):
   """
 
   def __init__(self,prefix):
-    self.prefix = prefix
-    self.nodecache = {}
+    self._prefix = prefix
+    self._nodecache = {}
 
-  def node(self,localName):
-    if localName not in self.nodecache:
-      self.nodecache[localName] = Redland.librdf_new_node_from_uri_string(_world._world, self.prefix+localName)
-    return Node(from_object=self.nodecache[localName])
+  def _node(self,localName):
+    if localName not in self._nodecache:
+      self._nodecache[localName] = Redland.librdf_new_node_from_uri_string(_world._world, self._prefix+localName)
+    return Node(from_object=self._nodecache[localName])
 
   def __getitem__(self,localName):
-    return self.node(localName)
+    return self._node(localName)
 
   def __getattr__(self,localName):
-    return self.node(localName)
+    return self._node(localName)
 
 
 # global init, create our world.
