@@ -5,6 +5,7 @@ require 'rdf/redland/statement'
 require 'rdf/redland/util'
 require 'rdf/redland/node'
 require 'rdf/redland/parser'
+require 'rdf/redland/queryresults'
 require 'rdf/redland/query'
 require 'rdf/redland/resource'
 require 'rdf/redland/serializer'
@@ -12,8 +13,6 @@ require 'rdf/redland/uri'
 require 'rdf/redland/resource'
 require 'rdf/redland/util'
 
-require 'log4r'
-
 # This module initialises the Redland library and references all
 # resources from it.
 
