@@ -44,7 +44,8 @@ module Redland
     # get a resource given by str.  If arg is a string it will create a
     # Resource from it.
     def get_resource(arg)
-      return self.find(Resource.new(arg),nil,nil)[0].subject
+      res = self.find(Resource.new(arg),nil,nil)
+      return (res.nil? || res[0].nil?) ? nil : res[0].subject
     end
 
     # Return the size of the Storage Model.  Raises a redland error if the model
@@ -409,6 +410,16 @@ module Redland
 
     private :get_size
 
+    # execute a query
+    def query_execute(query)
+      results=Redland.librdf_model_query_execute(@model, query.query)
+      if not results
+        return nil
+      else
+        return QueryResults.new(results)
+      end
+    end
+
     
   end
 
