@@ -6,10 +6,14 @@ require 'rdf/redland/stream'
 module Redland
 
   # The Parser class for rdf.  There are currently three types of parsers
-  # *'raptor'- a rdf parser
+  # *'rdfxml'- a rdf parser
   # *'ntriples' a An triples parser
   # *'turtle' - a parser for the turtle syntax as defined in
-  #  http://www.ilrt.bris.ac.uk/discovery/2004/01/turtle/
+  #  http://www.dajobe.org/2004/01/turtle/
+  # *'rss-tag-soup' - a parser for all RSS flavours and some atom
+  # *'grddl' - GRDDL
+  #
+  # The last two may or may not be available depending on systems.
   #
   #   model = Model.new()
   #   parser = Parser.ntriples()
@@ -17,8 +21,8 @@ module Redland
   class Parser
     attr_accessor :context
     
-    # create a new Parser. if no name is given, it defaults to parsing rdf syntax
-    def initialize(name='raptor',mime_type="application/rdf+xml",uri=nil,context=nil)
+    # create a new Parser. if no name is given, it defaults to parsing RDF/XML syntax
+    def initialize(name='rdfxml',mime_type="application/rdf+xml",uri=nil,context=nil)
       @context = nil
       @idents = []
       uri=uri.uri if uri
@@ -36,12 +40,12 @@ module Redland
 
     # create a parser for the ntriples syntax
     def Parser.ntriples(uri=nil)
-      return Parser.new('ntriples','text/plain',uri)
+      return Parser.new('ntriples',"",uri)
     end
 
     # create a parser for rdf syntax
     def Parser.raptor(uri=nil)
-      initialize('raptor','application/rdf+xml',uri)
+      initialize('rdfxml','application/rdf+xml',uri)
     end
     
     # Parse the given uri with optional base_uri and return a
@@ -72,24 +76,29 @@ module Redland
     # given then the content is parsed as if it was at the base_uri rather
     # than the uri.  If the optional context is given, the statement is added to the context
     def parse_into_model(model,uri,base_uri=nil,context=@context)
+      #puts "parse_into_model context is #{context}"
+      if uri.class == String
+        uri = Uri.new(uri)
+      end
+      if base_uri
+        if base_uri.class == String
+          base_uri = Uri.new(base_uri)
+        end
+      else
+        base_uri=uri 
+      end
       if not context
-        if uri.class == String
-          uri = Uri.new(uri)
-        end
-        if base_uri
-          if base_uri.class == String
-            base_uri = Uri.new(base_uri)
-          end
-        else
-          base_uri=uri 
-        end
         begin
           r = Redland.librdf_parser_parse_into_model(@parser,uri.uri,base_uri.uri,model.model)
         rescue RedlandError => err
           print "caught error"+ err
         end
       else #context
-        self.parse_as_stream(uri,base_uri){|s| model.add_statement(s,context)}
+        raise RedlandError.new("Cannot make a Node from an object of #{context.class}") if not context
+        context = Node.ensure(context)
+ 	my_stream = Redland::librdf_parser_parse_as_stream(@parser,uri.uri,base_uri.uri)
+        Redland.librdf_model_context_add_statements(model.model,context,my_stream)
+        #self.parse_as_stream(uri,base_uri){|s| model.add_statement(s,context)}
       end
 
     end
